//[mahjong-utils](../../../index.md)/[mahjongutils.models](../index.md)/[Pon](index.md)/[asMentsu](as-mentsu.md)

# asMentsu

[common]\
open override fun [asMentsu](as-mentsu.md)(): [Kotsu](../-kotsu/index.md)

获取副露的面子
